@@ -318,7 +318,7 @@ def fedpredict_dynamic_core(t, T, nt, s=1, fc=None, il=None, dh=None, ps=None, l
 
         if fc is not None and il is not None and dh is not None and ps is not None:
             if (fc["global"] > fc["reference"] and il["global"] < il["reference"] and dh["global"] > dh[
-                "reference"]) and (nt > 0 and ps["global"] < ps["reference"] and dh["global"] > dh["reference"]):
+                "reference"]) and (nt > 0 and ps["global"] > ps["reference"] and dh["global"] < dh["reference"]):
                 global_model_weight = 1
 
         local_model_weights = 1 - global_model_weight
@@ -618,8 +618,7 @@ def fedpredict_server(global_model_parameters: Union[List[np.array], torch.nn.Mo
             elif compression == 'fedkd':
                 if fedkd is None:
                     parameters_to_send = parameters_to_send if parameters_to_send is not None else global_model_parameters
-                    parameters_to_send, layers_fraction = fedkd_compression(lt, layers_compression_range, T, t, len(M),
-                                                                            parameters_to_send)
+                    parameters_to_send = fedkd_compression(layers_compression_range, T, t, parameters_to_send)
                     fedkd = parameters_to_send
                 else:
                     # Reuse compressed parameters
