@@ -112,7 +112,7 @@ def fedpredict_client_weight_predictions_torch(output: torch.Tensor, t: int, cur
     try:
         if similarity != 1 and t > 10:
             if _has_torch:
-                output = torch.multiply(output, torch.from_numpy(current_proportion * (1 - similarity)))
+                output = torch.multiply(output, torch.from_numpy(current_proportion * (1 - similarity)).to(output.device))
             else:
                 raise ValueError("Framework 'torch' not found")
 
@@ -178,7 +178,7 @@ def fedpredict_client_torch(local_model: torch.nn.Module,
                 Example:
                     il = {'global': 0.5, 'reference': 0.5}
             dh: dict[str,float], optional. Default=None.
-                The degree of data homogeneity that generated the global model.
+                The degree of data heterogeneity (changed from "data homogeneity" to "data heterogeneity" that generated the global model.
                 Example:
                     dh = {'global': 0.5, 'reference': 0.5}
             ps: dict[str,float], optional. Default=None.
